Index: trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.Designer.cs
===================================================================
--- trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.Designer.cs	(revision 1627)
+++ trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.Designer.cs	(revision 1628)
@@ -31,7 +31,6 @@
       this.addToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
       this.jobToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
-      this.ilClientControl = new System.Windows.Forms.ImageList(this.components);
-      this.ilJobControl = new System.Windows.Forms.ImageList(this.components);
-      this.ilUserControl = new System.Windows.Forms.ImageList(this.components);
+      this.ilLargeImgJob = new System.Windows.Forms.ImageList(this.components);
+      this.ilLargeImgClient = new System.Windows.Forms.ImageList(this.components);
       this.plClientDetails = new System.Windows.Forms.Panel();
       this.lblState = new System.Windows.Forms.Label();
@@ -70,12 +69,18 @@
       this.scJobControl = new System.Windows.Forms.SplitContainer();
       this.lvJobControl = new System.Windows.Forms.ListView();
+      this.contextMenuJob = new System.Windows.Forms.ContextMenuStrip(this.components);
+      this.menuItemAbortJob = new System.Windows.Forms.ToolStripMenuItem();
+      this.menuItemGetSnapshot = new System.Windows.Forms.ToolStripMenuItem();
       this.tpClientControl = new System.Windows.Forms.TabPage();
       this.scClientControl = new System.Windows.Forms.SplitContainer();
       this.lvClientControl = new System.Windows.Forms.ListView();
-      this.contextMenuJob = new System.Windows.Forms.ContextMenuStrip(this.components);
-      this.menuItemAbortJob = new System.Windows.Forms.ToolStripMenuItem();
-      this.menuItemGetSnapshot = new System.Windows.Forms.ToolStripMenuItem();
       this.tcManagementConsole = new System.Windows.Forms.TabControl();
       this.checkBox1 = new System.Windows.Forms.CheckBox();
+      this.viewToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
+      this.largeIconsToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
+      this.smallIconsToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
+      this.listToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
+      this.ilSmallImgJob = new System.Windows.Forms.ImageList(this.components);
+      this.ilSmallImgClient = new System.Windows.Forms.ImageList(this.components);
       this.menuStrip1.SuspendLayout();
       this.plClientDetails.SuspendLayout();
@@ -90,9 +95,9 @@
       this.scJobControl.Panel2.SuspendLayout();
       this.scJobControl.SuspendLayout();
+      this.contextMenuJob.SuspendLayout();
       this.tpClientControl.SuspendLayout();
       this.scClientControl.Panel1.SuspendLayout();
       this.scClientControl.Panel2.SuspendLayout();
       this.scClientControl.SuspendLayout();
-      this.contextMenuJob.SuspendLayout();
       this.tcManagementConsole.SuspendLayout();
       this.SuspendLayout();
@@ -102,5 +107,6 @@
       this.menuStrip1.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
             this.informationToolStripMenuItem,
-            this.addToolStripMenuItem});
+            this.addToolStripMenuItem,
+            this.viewToolStripMenuItem});
       this.menuStrip1.Location = new System.Drawing.Point(0, 0);
       this.menuStrip1.Name = "menuStrip1";
@@ -135,28 +141,22 @@
       // 
       this.jobToolStripMenuItem.Name = "jobToolStripMenuItem";
-      this.jobToolStripMenuItem.Size = new System.Drawing.Size(102, 22);
+      this.jobToolStripMenuItem.Size = new System.Drawing.Size(152, 22);
       this.jobToolStripMenuItem.Text = "Job";
       this.jobToolStripMenuItem.Click += new System.EventHandler(this.AddJob_Click);
       // 
-      // ilClientControl
-      // 
-      this.ilClientControl.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilClientControl.ImageStream")));
-      this.ilClientControl.TransparentColor = System.Drawing.Color.Transparent;
-      this.ilClientControl.Images.SetKeyName(0, "monitor-green.png");
-      this.ilClientControl.Images.SetKeyName(1, "monitor-orange.png");
-      this.ilClientControl.Images.SetKeyName(2, "monitor-red.png");
-      this.ilClientControl.Images.SetKeyName(3, "monitor-gray.png");
-      // 
-      // ilJobControl
-      // 
-      this.ilJobControl.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilJobControl.ImageStream")));
-      this.ilJobControl.TransparentColor = System.Drawing.Color.Transparent;
-      this.ilJobControl.Images.SetKeyName(0, "PlayHS.png");
-      // 
-      // ilUserControl
-      // 
-      this.ilUserControl.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilUserControl.ImageStream")));
-      this.ilUserControl.TransparentColor = System.Drawing.Color.Transparent;
-      this.ilUserControl.Images.SetKeyName(0, "Users.png");
+      // ilLargeImgJob
+      // 
+      this.ilLargeImgJob.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilLargeImgJob.ImageStream")));
+      this.ilLargeImgJob.TransparentColor = System.Drawing.Color.Transparent;
+      this.ilLargeImgJob.Images.SetKeyName(0, "monitor-green.png");
+      this.ilLargeImgJob.Images.SetKeyName(1, "monitor-orange.png");
+      this.ilLargeImgJob.Images.SetKeyName(2, "monitor-red.png");
+      this.ilLargeImgJob.Images.SetKeyName(3, "monitor-gray.png");
+      // 
+      // ilLargeImgClient
+      // 
+      this.ilLargeImgClient.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilLargeImgClient.ImageStream")));
+      this.ilLargeImgClient.TransparentColor = System.Drawing.Color.Transparent;
+      this.ilLargeImgClient.Images.SetKeyName(0, "PlayHS.png");
       // 
       // plClientDetails
@@ -496,9 +496,10 @@
       this.lvJobControl.ContextMenuStrip = this.contextMenuJob;
       this.lvJobControl.Dock = System.Windows.Forms.DockStyle.Fill;
-      this.lvJobControl.LargeImageList = this.ilJobControl;
+      this.lvJobControl.LargeImageList = this.ilLargeImgJob;
       this.lvJobControl.Location = new System.Drawing.Point(0, 0);
       this.lvJobControl.MultiSelect = false;
       this.lvJobControl.Name = "lvJobControl";
       this.lvJobControl.Size = new System.Drawing.Size(454, 386);
+      this.lvJobControl.SmallImageList = this.ilSmallImgJob;
       this.lvJobControl.TabIndex = 0;
       this.lvJobControl.UseCompatibleStateImageBehavior = false;
@@ -506,4 +507,24 @@
       this.lvJobControl.MouseMove += new System.Windows.Forms.MouseEventHandler(this.lvJobControl_MouseMove);
       this.lvJobControl.Click += new System.EventHandler(this.OnLVJobControlClicked);
+      // 
+      // contextMenuJob
+      // 
+      this.contextMenuJob.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
+            this.menuItemAbortJob,
+            this.menuItemGetSnapshot});
+      this.contextMenuJob.Name = "contextMenuJob";
+      this.contextMenuJob.Size = new System.Drawing.Size(151, 48);
+      // 
+      // menuItemAbortJob
+      // 
+      this.menuItemAbortJob.Name = "menuItemAbortJob";
+      this.menuItemAbortJob.Size = new System.Drawing.Size(150, 22);
+      this.menuItemAbortJob.Text = "Abort";
+      // 
+      // menuItemGetSnapshot
+      // 
+      this.menuItemGetSnapshot.Name = "menuItemGetSnapshot";
+      this.menuItemGetSnapshot.Size = new System.Drawing.Size(150, 22);
+      this.menuItemGetSnapshot.Text = "Get Snapshot";
       // 
       // tpClientControl
@@ -541,32 +562,13 @@
       this.lvClientControl.Dock = System.Windows.Forms.DockStyle.Fill;
       this.lvClientControl.ImeMode = System.Windows.Forms.ImeMode.Off;
-      this.lvClientControl.LargeImageList = this.ilClientControl;
+      this.lvClientControl.LargeImageList = this.ilLargeImgClient;
       this.lvClientControl.Location = new System.Drawing.Point(0, 0);
       this.lvClientControl.MultiSelect = false;
       this.lvClientControl.Name = "lvClientControl";
       this.lvClientControl.Size = new System.Drawing.Size(454, 386);
+      this.lvClientControl.SmallImageList = this.ilSmallImgClient;
       this.lvClientControl.TabIndex = 0;
       this.lvClientControl.UseCompatibleStateImageBehavior = false;
       this.lvClientControl.Click += new System.EventHandler(this.OnLVClientClicked);
-      // 
-      // contextMenuJob
-      // 
-      this.contextMenuJob.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
-            this.menuItemAbortJob,
-            this.menuItemGetSnapshot});
-      this.contextMenuJob.Name = "contextMenuJob";
-      this.contextMenuJob.Size = new System.Drawing.Size(151, 48);
-      // 
-      // menuItemAbortJob
-      // 
-      this.menuItemAbortJob.Name = "menuItemAbortJob";
-      this.menuItemAbortJob.Size = new System.Drawing.Size(150, 22);
-      this.menuItemAbortJob.Text = "Abort";
-      // 
-      // menuItemGetSnapshot
-      // 
-      this.menuItemGetSnapshot.Name = "menuItemGetSnapshot";
-      this.menuItemGetSnapshot.Size = new System.Drawing.Size(150, 22);
-      this.menuItemGetSnapshot.Text = "Get Snapshot";
       // 
       // tcManagementConsole
@@ -590,4 +592,52 @@
       this.checkBox1.Text = "checkBox1";
       this.checkBox1.UseVisualStyleBackColor = true;
+      // 
+      // viewToolStripMenuItem
+      // 
+      this.viewToolStripMenuItem.DropDownItems.AddRange(new System.Windows.Forms.ToolStripItem[] {
+            this.largeIconsToolStripMenuItem,
+            this.smallIconsToolStripMenuItem,
+            this.listToolStripMenuItem});
+      this.viewToolStripMenuItem.Name = "viewToolStripMenuItem";
+      this.viewToolStripMenuItem.Size = new System.Drawing.Size(41, 20);
+      this.viewToolStripMenuItem.Text = "View";
+      // 
+      // largeIconsToolStripMenuItem
+      // 
+      this.largeIconsToolStripMenuItem.Checked = true;
+      this.largeIconsToolStripMenuItem.CheckState = System.Windows.Forms.CheckState.Checked;
+      this.largeIconsToolStripMenuItem.Name = "largeIconsToolStripMenuItem";
+      this.largeIconsToolStripMenuItem.Size = new System.Drawing.Size(152, 22);
+      this.largeIconsToolStripMenuItem.Text = "Large Icons";
+      this.largeIconsToolStripMenuItem.Click += new System.EventHandler(this.largeIconsToolStripMenuItem_Click);
+      // 
+      // smallIconsToolStripMenuItem
+      // 
+      this.smallIconsToolStripMenuItem.Name = "smallIconsToolStripMenuItem";
+      this.smallIconsToolStripMenuItem.Size = new System.Drawing.Size(152, 22);
+      this.smallIconsToolStripMenuItem.Text = "Small Icons";
+      this.smallIconsToolStripMenuItem.Click += new System.EventHandler(this.smallIconsToolStripMenuItem_Click);
+      // 
+      // listToolStripMenuItem
+      // 
+      this.listToolStripMenuItem.Name = "listToolStripMenuItem";
+      this.listToolStripMenuItem.Size = new System.Drawing.Size(152, 22);
+      this.listToolStripMenuItem.Text = "List";
+      this.listToolStripMenuItem.Click += new System.EventHandler(this.listToolStripMenuItem_Click);
+      // 
+      // ilSmallImgJob
+      // 
+      this.ilSmallImgJob.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilSmallImgJob.ImageStream")));
+      this.ilSmallImgJob.TransparentColor = System.Drawing.Color.Transparent;
+      this.ilSmallImgJob.Images.SetKeyName(0, "monitor-green.png");
+      this.ilSmallImgJob.Images.SetKeyName(1, "monitor-orange.png");
+      this.ilSmallImgJob.Images.SetKeyName(2, "monitor-red.png");
+      this.ilSmallImgJob.Images.SetKeyName(3, "monitor-gray.png");
+      // 
+      // ilSmallImgClient
+      // 
+      this.ilSmallImgClient.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("ilSmallImgClient.ImageStream")));
+      this.ilSmallImgClient.TransparentColor = System.Drawing.Color.Transparent;
+      this.ilSmallImgClient.Images.SetKeyName(0, "PlayHS.png");
       // 
       // HiveServerManagementConsole
@@ -618,9 +668,9 @@
       this.scJobControl.Panel2.ResumeLayout(false);
       this.scJobControl.ResumeLayout(false);
+      this.contextMenuJob.ResumeLayout(false);
       this.tpClientControl.ResumeLayout(false);
       this.scClientControl.Panel1.ResumeLayout(false);
       this.scClientControl.Panel2.ResumeLayout(false);
       this.scClientControl.ResumeLayout(false);
-      this.contextMenuJob.ResumeLayout(false);
       this.tcManagementConsole.ResumeLayout(false);
       this.ResumeLayout(false);
@@ -636,10 +686,9 @@
     private System.Windows.Forms.TreeView treeView2;
     private System.Windows.Forms.ListView listView2;
-    private System.Windows.Forms.ImageList ilClientControl;
+    private System.Windows.Forms.ImageList ilLargeImgJob;
     private System.Windows.Forms.ToolStripMenuItem addToolStripMenuItem;
     private System.Windows.Forms.ToolStripMenuItem jobToolStripMenuItem;
-    private System.Windows.Forms.ImageList ilUserControl;
     private System.Windows.Forms.Timer timerSyncronize;
-    private System.Windows.Forms.ImageList ilJobControl;
+    private System.Windows.Forms.ImageList ilLargeImgClient;
     private System.Windows.Forms.Panel plClientDetails;
     private System.Windows.Forms.PictureBox pbClientControl;
@@ -683,4 +732,10 @@
     private System.Windows.Forms.ToolStripMenuItem menuItemAbortJob;
     private System.Windows.Forms.ToolStripMenuItem menuItemGetSnapshot;
+    private System.Windows.Forms.ToolStripMenuItem viewToolStripMenuItem;
+    private System.Windows.Forms.ToolStripMenuItem largeIconsToolStripMenuItem;
+    private System.Windows.Forms.ToolStripMenuItem smallIconsToolStripMenuItem;
+    private System.Windows.Forms.ToolStripMenuItem listToolStripMenuItem;
+    private System.Windows.Forms.ImageList ilSmallImgJob;
+    private System.Windows.Forms.ImageList ilSmallImgClient;
   }
 }
Index: trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.resx
===================================================================
--- trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.resx	(revision 1627)
+++ trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.resx	(revision 1628)
@@ -121,8 +121,8 @@
     <value>32, 12</value>
   </metadata>
-  <metadata name="ilClientControl.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+  <metadata name="ilLargeImgJob.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
     <value>129, 12</value>
   </metadata>
-  <data name="ilClientControl.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
+  <data name="ilLargeImgJob.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
     <value>
         AAEAAAD/////AQAAAAAAAAAMAgAAAFdTeXN0ZW0uV2luZG93cy5Gb3JtcywgVmVyc2lvbj0yLjAuMC4w
@@ -231,8 +231,8 @@
 </value>
   </data>
-  <metadata name="ilJobControl.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>471, 13</value>
-  </metadata>
-  <data name="ilJobControl.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
+  <metadata name="ilLargeImgClient.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>228, 11</value>
+  </metadata>
+  <data name="ilLargeImgClient.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
     <value>
         AAEAAAD/////AQAAAAAAAAAMAgAAAFdTeXN0ZW0uV2luZG93cy5Gb3JtcywgVmVyc2lvbj0yLjAuMC4w
@@ -283,14 +283,90 @@
 </value>
   </data>
-  <metadata name="ilUserControl.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>231, 9</value>
-  </metadata>
-  <data name="ilUserControl.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
+  <metadata name="timerSyncronize.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>341, 9</value>
+  </metadata>
+  <metadata name="fileSystemWatcher1.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>462, 9</value>
+  </metadata>
+  <metadata name="updaterWoker.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>388, 41</value>
+  </metadata>
+  <metadata name="contextMenuJob.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>252, 44</value>
+  </metadata>
+  <metadata name="ilSmallImgJob.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>17, 50</value>
+  </metadata>
+  <data name="ilSmallImgJob.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
     <value>
         AAEAAAD/////AQAAAAAAAAAMAgAAAFdTeXN0ZW0uV2luZG93cy5Gb3JtcywgVmVyc2lvbj0yLjAuMC4w
         LCBDdWx0dXJlPW5ldXRyYWwsIFB1YmxpY0tleVRva2VuPWI3N2E1YzU2MTkzNGUwODkFAQAAACZTeXN0
-        ZW0uV2luZG93cy5Gb3Jtcy5JbWFnZUxpc3RTdHJlYW1lcgEAAAAERGF0YQcCAgAAAAkDAAAADwMAAACs
-        CwAAAk1TRnQBSQFMAwEBAAEEAQABBAEAASABAAEgAQAE/wEJAQAI/wFCAU0BNgEEBgABNgEEAgABKAMA
-        AYADAAEgAwABAQEAAQgGAAEQGAABgAIAAYADAAKAAQABgAMAAYABAAGAAQACgAIAA8ABAAHAAdwBwAEA
+        ZW0uV2luZG93cy5Gb3Jtcy5JbWFnZUxpc3RTdHJlYW1lcgEAAAAERGF0YQcCAgAAAAkDAAAADwMAAABy
+        DAAAAk1TRnQBSQFMAgEBBAEAAQUBAAEEAQABEAEAARABAAT/AQkBAAj/AUIBTQE2AQQGAAE2AQQCAAEo
+        AwABQAMAASADAAEBAQABCAYAAQgYAAGAAgABgAMAAoABAAGAAwABgAEAAYABAAKAAgADwAEAAcAB3AHA
+        AQAB8AHKAaYBAAEzBQABMwEAATMBAAEzAQACMwIAAxYBAAMcAQADIgEAAykBAANVAQADTQEAA0IBAAM5
+        AQABgAF8Af8BAAJQAf8BAAGTAQAB1gEAAf8B7AHMAQABxgHWAe8BAAHWAucBAAGQAakBrQIAAf8BMwMA
+        AWYDAAGZAwABzAIAATMDAAIzAgABMwFmAgABMwGZAgABMwHMAgABMwH/AgABZgMAAWYBMwIAAmYCAAFm
+        AZkCAAFmAcwCAAFmAf8CAAGZAwABmQEzAgABmQFmAgACmQIAAZkBzAIAAZkB/wIAAcwDAAHMATMCAAHM
+        AWYCAAHMAZkCAALMAgABzAH/AgAB/wFmAgAB/wGZAgAB/wHMAQABMwH/AgAB/wEAATMBAAEzAQABZgEA
+        ATMBAAGZAQABMwEAAcwBAAEzAQAB/wEAAf8BMwIAAzMBAAIzAWYBAAIzAZkBAAIzAcwBAAIzAf8BAAEz
+        AWYCAAEzAWYBMwEAATMCZgEAATMBZgGZAQABMwFmAcwBAAEzAWYB/wEAATMBmQIAATMBmQEzAQABMwGZ
+        AWYBAAEzApkBAAEzAZkBzAEAATMBmQH/AQABMwHMAgABMwHMATMBAAEzAcwBZgEAATMBzAGZAQABMwLM
+        AQABMwHMAf8BAAEzAf8BMwEAATMB/wFmAQABMwH/AZkBAAEzAf8BzAEAATMC/wEAAWYDAAFmAQABMwEA
+        AWYBAAFmAQABZgEAAZkBAAFmAQABzAEAAWYBAAH/AQABZgEzAgABZgIzAQABZgEzAWYBAAFmATMBmQEA
+        AWYBMwHMAQABZgEzAf8BAAJmAgACZgEzAQADZgEAAmYBmQEAAmYBzAEAAWYBmQIAAWYBmQEzAQABZgGZ
+        AWYBAAFmApkBAAFmAZkBzAEAAWYBmQH/AQABZgHMAgABZgHMATMBAAFmAcwBmQEAAWYCzAEAAWYBzAH/
+        AQABZgH/AgABZgH/ATMBAAFmAf8BmQEAAWYB/wHMAQABzAEAAf8BAAH/AQABzAEAApkCAAGZATMBmQEA
+        AZkBAAGZAQABmQEAAcwBAAGZAwABmQIzAQABmQEAAWYBAAGZATMBzAEAAZkBAAH/AQABmQFmAgABmQFm
+        ATMBAAGZATMBZgEAAZkBZgGZAQABmQFmAcwBAAGZATMB/wEAApkBMwEAApkBZgEAA5kBAAKZAcwBAAKZ
+        Af8BAAGZAcwCAAGZAcwBMwEAAWYBzAFmAQABmQHMAZkBAAGZAswBAAGZAcwB/wEAAZkB/wIAAZkB/wEz
+        AQABmQHMAWYBAAGZAf8BmQEAAZkB/wHMAQABmQL/AQABzAMAAZkBAAEzAQABzAEAAWYBAAHMAQABmQEA
+        AcwBAAHMAQABmQEzAgABzAIzAQABzAEzAWYBAAHMATMBmQEAAcwBMwHMAQABzAEzAf8BAAHMAWYCAAHM
+        AWYBMwEAAZkCZgEAAcwBZgGZAQABzAFmAcwBAAGZAWYB/wEAAcwBmQIAAcwBmQEzAQABzAGZAWYBAAHM
+        ApkBAAHMAZkBzAEAAcwBmQH/AQACzAIAAswBMwEAAswBZgEAAswBmQEAA8wBAALMAf8BAAHMAf8CAAHM
+        Af8BMwEAAZkB/wFmAQABzAH/AZkBAAHMAf8BzAEAAcwC/wEAAcwBAAEzAQAB/wEAAWYBAAH/AQABmQEA
+        AcwBMwIAAf8CMwEAAf8BMwFmAQAB/wEzAZkBAAH/ATMBzAEAAf8BMwH/AQAB/wFmAgAB/wFmATMBAAHM
+        AmYBAAH/AWYBmQEAAf8BZgHMAQABzAFmAf8BAAH/AZkCAAH/AZkBMwEAAf8BmQFmAQAB/wKZAQAB/wGZ
+        AcwBAAH/AZkB/wEAAf8BzAIAAf8BzAEzAQAB/wHMAWYBAAH/AcwBmQEAAf8CzAEAAf8BzAH/AQAC/wEz
+        AQABzAH/AWYBAAL/AZkBAAL/AcwBAAJmAf8BAAFmAf8BZgEAAWYC/wEAAf8CZgEAAf8BZgH/AQAC/wFm
+        AQABIQEAAaUBAANfAQADdwEAA4YBAAOWAQADywEAA7IBAAPXAQAD3QEAA+MBAAPqAQAD8QEAA/gBAAHw
+        AfsB/wEAAaQCoAEAA4ADAAH/AgAB/wMAAv8BAAH/AwAB/wEAAf8BAAL/AgAD//8A/wD/AP8ABQAFNQFW
+        AQcC8AG8AXgBVgQ1BSwBUgEHAvABvAF0AU0ELAVAAWkBBwLwAbwBbwVABpIBBwHwArwGkgQ1Ae8BvAHw
+        AfEC8AIHAVABLgI0BCwBmQG8AfAB8QLwAgcBbgIrASwEQAGTAbwB8AHxAvACBwFoAekBIAFABJIBBwG8
+        AfAB8QLwAgcB7AOSAzUBVgIHAbwB8AG8AQcB7wLtAzQDLAFTAgcBvAHwAbwBBwHvAe0BHAIrASwEQAIH
+        AbwB8AG8AQcB7wLtAiABQASSAgcBvAHwAbwBBwHvAe0B9wOSBDUBVgPvAewBbQHrAvcB7wI0BCwBTAEH
+        Au8B7AFtAesB9wEcAe8CLARAAUYD7wHsAW0B6wH3ARwB7wJABZID7wHsAW0B6wL3Ae8CkgU1ATQBUAHs
+        Ae0BBwG8AQcB9wEHAjUGLAFMAewB7QEHAbwBBwH3AQcCLAZAAUUB7AHtAQcBvAEHAfcBBwJAB5IB7AHt
+        AQcBvAEHAfcBBwKSATUBVgHsAfcCBwHvAewBFAFDAREBQwEUAbwBVgE1ASwBTAHsAe8CBwHvAewBFAFD
+        AREBQwEUAbwBUwEsAUABRgFuAfcCBwHvAewBFAFDAREBQwEUAbwBRgFAApIB7AH3AgcB7wHsARQBQwER
+        AUMBFAG8ApIBNQH3AewBFQIPARABEQEVARMDEgG8AVYBNQEsAfcB7AEVAg8BEAERARUBEwMSAbwBUgEs
+        AUAB9wHsARUCDwEQAREBFQETAxIBvAFGAUABkgH3AewBFQIPARABEQEVARMDEgG8ApIBNQHvAxEBEAER
+        AUMBEwJtAusBBwGXATUBLAHvAxEBEAERAUMBEwJtAusBBwF0ASwBQAHvAxEBEAERAUMBEwJtAusBBwFv
+        AUABkgHvAxEBEAERAUMBEwJtAusBBwHtAZIBNQHvARUBFAIRAkMBbQLsAu0BBwFzATUBLAHvARUBFAIR
+        AkMBbQLsAu0BBwEcASwBQAHvARUBFAIRAkMBbQLsAu0BBwFuAUABkgHvARUBFAIRAkMBbQLsAu0BBwHt
+        AZIBNQGYARQB6gIRAUMBFQHsAfcE7wHtATUBLAGZARQB6gIRAUMBFQHsAfcE7wEcASwBQAGTARQB6gIR
+        AUMBFQHsAfcE7wHtAUABkgHvARQB6gIRAUMBFQHsAfcE7wH3AZIBNQF4ARMBEgERAUMBFQEUAe8DBwG8
+        AQcBkgE1ASwBdAETARIBEQFDARUBFAHvAwcBvAEHARwBLAFAAW8BEwESAREBQwEVARQB7wMHAbwBBwGS
+        AUAB7QGSARMBEgERAUMBFQEUAe8DBwG8AQcB9wGSATUBVgESAkMBFQEUAeoD8ALxAQcB7wE1ASwBUwES
+        AkMBFQEUAeoD8ALxAQcB7wEsAUABRgESAkMBFQEUAeoD8ALxAQcB7wFAAe0BkgESAkMBFQEUAeoD8ALx
+        AQcB7wGSAjUBEgERAUMBFQEUAewD8gLzAfEBvAE1ASwBTQESAREBQwEVARQB7APyAvMB8QG8ASwCQAES
+        AREBQwEVARQB7APyAvMB8QG8AUACkgESAREBQwEVARQB7APyAvMB8QG8AZICNQHsAREBQwEVARQB7wHx
+        ArwCBwG8AfEBNQIsAewBEQFDARUBFAHvAfECvAIHAbwB8QFNAkAB7AERAUMBFQEUAe8B8QK8AgcBvAHx
+        AUACkgHsAREBQwEVARQB7wHxArwDBwHxAZICNQH3ARQBbQGSAQcBvAEIAZkBmAJ4AlYBNQIsAfcBFAFt
+        AZIBBwG8AQcBmQGTAXQBdQJTASwCQAH3ARQBbQGSAQcBvAEHApMBjgFvAkYBQAKSAfcBFAFtAZIBBwG8
+        AQgB9waSAjUDVgs1AiwDUwssAkACaQFGC0AQkgFCAU0BPgcAAT4DAAEoAwABQAMAASADAAEBAQABAQYA
+        AQEWAAP//wACAAs=
+</value>
+  </data>
+  <metadata name="ilSmallImgClient.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
+    <value>137, 50</value>
+  </metadata>
+  <data name="ilSmallImgClient.ImageStream" mimetype="application/x-microsoft.net.object.binary.base64">
+    <value>
+        AAEAAAD/////AQAAAAAAAAAMAgAAAFdTeXN0ZW0uV2luZG93cy5Gb3JtcywgVmVyc2lvbj0yLjAuMC4w
+        LCBDdWx0dXJlPW5ldXRyYWwsIFB1YmxpY0tleVRva2VuPWI3N2E1YzU2MTkzNGUwODkFAQAAACZTeXN0
+        ZW0uV2luZG93cy5Gb3Jtcy5JbWFnZUxpc3RTdHJlYW1lcgEAAAAERGF0YQcCAgAAAAkDAAAADwMAAAC0
+        BwAAAk1TRnQBSQFMAwEBAAEFAQABBAEAARABAAEQAQAE/wEJAQAI/wFCAU0BNgEEBgABNgEEAgABKAMA
+        AUADAAEQAwABAQEAAQgGAAEEGAABgAIAAYADAAKAAQABgAMAAYABAAGAAQACgAIAA8ABAAHAAdwBwAEA
         AfABygGmAQABMwUAATMBAAEzAQABMwEAAjMCAAMWAQADHAEAAyIBAAMpAQADVQEAA00BAANCAQADOQEA
         AYABfAH/AQACUAH/AQABkwEAAdYBAAH/AewBzAEAAcYB1gHvAQAB1gLnAQABkAGpAa0CAAH/ATMDAAFm
@@ -319,39 +395,10 @@
         AcwB/wFmAQAC/wGZAQAC/wHMAQACZgH/AQABZgH/AWYBAAFmAv8BAAH/AmYBAAH/AWYB/wEAAv8BZgEA
         ASEBAAGlAQADXwEAA3cBAAOGAQADlgEAA8sBAAOyAQAD1wEAA90BAAPjAQAD6gEAA/EBAAP4AQAB8AH7
-        Af8BAAGkAqABAAOAAwAB/wIAAf8DAAL/AQAB/wMAAf8BAAH/AQAC/wIAA/8WAAWhewAFoXUAAqEBpwOG
-        BK0DhgGnA6FvAAGhAQQBtQcJArsBtQG0AYYCoW0AAaEBhgGLAbQCCQa7AbUCtAG1Aa0BBAGhbQABhgG0
-        AbsBtAEHAQkDuwEJA7sBtQK0AbMBBAGhYQAMoQGnArsBtAHvARkCuwMJArsBtQK0AbMBBAGhYQADoQGF
-        BwQBhQGGArsBtQEHAfMBCQG7BAkBuwK1AbQBiwGFAaFgAAKhAeoBbARtAUoB6wHsAW0BSgGRAbUCuwHv
-        AfMB3QG7BAkCuwG1AbQBhgKhYAABoQGGA3gDcwFyARwB7wFzAVABkQG0AQkBuwHvAfMBGQUJArsBtQG0
-        AYZiAAGhAesCeAFzAngBcwFyARwBBwEcAVEBcgG0AgkC7wEHArsDCQK7AbQBswGnYgABoQHsBngBcwHv
-        AbwBHAFzAVABcgG7ARkB9wNLAfcBuwEJA7sBswGFAaFiAAGhAa4BmQV4AZgBvAEIARwBeAFzAVABkQG7
-        Ae0BSwFKAUUBSwHtAbUBCQG1AbMBpwKhYwABrgGfAZgEeAGYAfEBBwGYAXgBcwFQAUoBiwHrAUsDRAFL
-        AZEBtAGGAqFlAAGnARwBmQR4ARwB7wEcAXIBUAJyAW0BEgFKAksCRAFLAYYBpwOhZQABoQGGARwBmAJ4
-        AXMCdAFzAeoBUAJyAW0FSwJKAadpAAKhAYsBmAF4AVABcwF0AnMBEgETAWYBhgHrBksB6gGnawABoQGn
-        AeoBSgNuAeoBZgEEAaEBpwHsA3MBbgJLAUoBp2sAAqEBEwFKAUsCdAFuAWYBFAGFAYYBcwN0AXMBbgJL
-        AWYBpwGhaQABoQFmAUoBSwF0ApMBdAFSAUoBZgGGAZIEdAFzAksBEwGGAaFpAAGGAXMBSwFRAZMDmQF0
-        AUsBZgGGARwCmQGTAnQBSwESAhQBoWkAAeoBdAFLAXQBmQGaA5kBSwKGAZkBmgKZAnQBSwIVARQBp2kA
-        AeoBdAFzAZkCGgGaAZkBHAHqAqcEmQGTAXQBbQIVARQBoWkAAYYBdAGTBBoBmgGZAWcBxAGhAe0BdAGT
-        AnQBbgESARQBFQFmAaFpAAGGAnQBGgLDARoBmgGZARICpwGuA+wB6wFtAeoBEwEUAYYBoWkAAacBdAFz
-        ARwBGgHDARoBmgGZAWcBxAGhAc8C7AHrAm0B6gIUAacBoWkAAacBrgEcAXQBcwFSAXQBkwFzARMBhgGh
-        AqcBhgKuAYYB6gGGAacCoWkAAaEBhgG8ApkBcwFRA0sBFAGFAaEDAAOhbQACoQG1AfADmQF5ARwBdAFt
-        AQQBoQMAA6FvAAGnAc8B7wKZARwBcwGuAad3AAGhB6cBofIAAUIBTQE+BwABPgMAASgDAAGAAwABIAMA
-        AQEBAAEBBgABAhYAA/8BAAL/AfgBPwwAAv8B+AE/DAAB/wH+DgAB/wH+DgAB/wH4DgAB/wH4DgABgA8A
-        AYAiAAEDDwABAw8AAQMPAAEDDAABgAIAAQ8MAAGAAgABDwwAAYACAAH/DAABgAIAAf8MAAHgAgAB/wwA
-        AeACAAE/DAAB4AIAAT8MAAHgAgABPwwAAeACAAE/DAAB4AIAAT8MAAHgAgABPwwAAeACAAE/DAAB4AIA
-        AT8MAAHgAgABPwwAAeABAAHjAf8MAAHgAQAB4wH/DAAB+AEDAv8MAAH4AQMC/wwABP8MAAs=
+        Af8BAAGkAqABAAOAAwAB/wIAAf8DAAL/AQAB/wMAAf8BAAH/AQAC/wIAA/+GAAGhPwABJwGhPgABKAEn
+        AaE9AAJJAScBoTwAAUkBTwFJAScBoTsAAUkBcgFPAUkBJwGhOgABTwGXAXIBTwFJASgBoTkAAU8ClwFy
+        AUkBpzoAAVABlwEIAUkBpzsAAXIBCAFJAac8AAFyAUkBpz0AAXIBpz4AAad6AAFCAU0BPgcAAT4DAAEo
+        AwABQAMAARADAAEBAQABAQUAAYAXAAP/AQAC/wYAAv8GAAH7Af8GAAH5Af8GAAH4Af8GAAH4AX8GAAH4
+        AT8GAAH4AR8GAAH4AQ8GAAH4AR8GAAH4AT8GAAH4AX8GAAH4Af8GAAH5Af8GAAH7Af8GAAL/BgAL
 </value>
   </data>
-  <metadata name="timerSyncronize.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>341, 9</value>
-  </metadata>
-  <metadata name="fileSystemWatcher1.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>580, 13</value>
-  </metadata>
-  <metadata name="contextMenuJob.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>730, 13</value>
-  </metadata>
-  <metadata name="updaterWoker.TrayLocation" type="System.Drawing.Point, System.Drawing, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>862, 13</value>
-  </metadata>
 </root>

Index: trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.cs
===================================================================
--- trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.cs	(revision 1627)
+++ trunk/sources/HeuristicLab.Hive.Server.Console/3.2/HiveServerManagementConsole.cs	(revision 1628)
@@ -88,4 +88,10 @@
     #endregion
 
+    private Guid ConvertStringToGuid(string stringGuid) {
+      Guid guid = Guid.Empty;
+      return (Guid)TypeDescriptor.GetConverter(guid).ConvertFrom(stringGuid);
+    }
+
+
     private void Init() {
 
@@ -94,7 +100,5 @@
         IJobManager jobManager = ServiceLocator.GetJobManager();
         if (lvJobControl.SelectedItems.Count == 1) {
-          Guid jobID = Guid.Empty;
-          jobID = (Guid)TypeDescriptor.GetConverter(jobID).ConvertFrom(lvJobControl.SelectedItems[0].Text);
-          jobManager.AbortJob(jobID);
+          jobManager.AbortJob(ConvertStringToGuid(lvJobControl.SelectedItems[0].Text));
         }
       };
@@ -103,7 +107,5 @@
         IJobManager jobManager = ServiceLocator.GetJobManager();
         if (lvJobControl.SelectedItems.Count == 1) {
-          Guid jobID = Guid.Empty;
-          jobID = (Guid)TypeDescriptor.GetConverter(jobID).ConvertFrom(lvJobControl.SelectedItems[0].Text);
-          jobManager.RequestSnapshot(jobID);
+          jobManager.RequestSnapshot(ConvertStringToGuid(lvJobControl.SelectedItems[0].Text));
         }
       };
@@ -113,8 +115,17 @@
     private void lvJobControl_MouseUp(object sender, MouseEventArgs e) {
       // If the right mouse button was clicked and released,
-      // display the shortcut menu assigned to the TreeView. 
-      if (e.Button == MouseButtons.Right && lvJobControl.SelectedItems.Count == 1) {
-        lvJobControl.ContextMenuStrip.Show(new Point(e.X, e.Y));
-      }
+      // display the shortcut menu assigned to the ListView. 
+      lvJobControl.ContextMenuStrip.Items.Clear();
+      ListViewHitTestInfo hitTestInfo = lvJobControl.HitTest(e.Location);
+      if (e.Button == MouseButtons.Right && hitTestInfo.Item != null && lvJobControl.SelectedItems.Count == 1) {
+        Guid selectedJobGuid = ConvertStringToGuid(lvJobControl.SelectedItems[0].Text);
+        Job selectedJob = jobs.List.FirstOrDefault(x => x.Id == selectedJobGuid);
+
+        if (selectedJob != null && selectedJob.State == State.calculating) {
+        lvJobControl.ContextMenuStrip.Items.Add(menuItemAbortJob);
+        lvJobControl.ContextMenuStrip.Items.Add(menuItemGetSnapshot);
+        }
+      }
+       lvJobControl.ContextMenuStrip.Show(new Point(e.X, e.Y));
     }
 
@@ -287,5 +298,5 @@
         }
       }
-      pbClientControl.Image = ilClientControl.Images[usage];
+      pbClientControl.Image = ilLargeImgJob.Images[usage];
       lblClientName.Text = currentClient.Name;
       lblLogin.Text = currentClient.Login.ToString();
@@ -305,5 +316,5 @@
       lvSnapshots.Enabled = true;
       currentJob = jobs.List[i];
-      pbJobControl.Image = ilJobControl.Images[0];
+      pbJobControl.Image = ilLargeImgClient.Images[0];
       lblJobName.Text = currentJob.Id.ToString();
       progressJob.Value = (int)(currentJob.Percentage * 100);
@@ -334,5 +345,5 @@
       if (currentJob.State != State.offline) {
         lvSnapshots.Items.Clear();
-        if (currentJob.State == State.finished) 
+        if (currentJob.State == State.finished)
           GetSnapshotList();
         lvSnapshots.Visible = true;
@@ -722,4 +733,28 @@
     #endregion
 
+    private void largeIconsToolStripMenuItem_Click(object sender, EventArgs e) {
+      lvClientControl.View = View.LargeIcon;
+      lvJobControl.View = View.LargeIcon;
+      largeIconsToolStripMenuItem.CheckState = CheckState.Checked;
+      smallIconsToolStripMenuItem.CheckState = CheckState.Unchecked;
+      listToolStripMenuItem.CheckState = CheckState.Unchecked;
+    }
+
+    private void smallIconsToolStripMenuItem_Click(object sender, EventArgs e) {
+      lvClientControl.View = View.SmallIcon;
+      lvJobControl.View = View.SmallIcon;
+      largeIconsToolStripMenuItem.CheckState = CheckState.Unchecked;
+      smallIconsToolStripMenuItem.CheckState = CheckState.Checked;
+      listToolStripMenuItem.CheckState = CheckState.Unchecked;
+    }
+
+    private void listToolStripMenuItem_Click(object sender, EventArgs e) {
+      lvClientControl.View = View.List;
+      lvJobControl.View = View.List;
+      largeIconsToolStripMenuItem.CheckState = CheckState.Unchecked;
+      smallIconsToolStripMenuItem.CheckState = CheckState.Unchecked;
+      listToolStripMenuItem.CheckState = CheckState.Checked;
+    }
+
 
 